MVPanalytics.keitaro:

    keitaro_parser(): функция для парсинга данных из кейтаро на любой вкус и цвет

MVPanalytics.analysis:

    weightgiver(): Функция для раздачи офферам в партнёрке весов (сплитование)

    off_analyzer(): Функция, позволяющая выявлять витрины по потоку (или офферу), на которых его: target < EPC, 0 < EPC < target, EPC=0

MVPanalytics.graphics:

    plot_acf_pacf(): Строит графики ACF и PACF для временного ряда.
